@@ -241,6 +241,9 @@ func (s *Stack) Preview(ctx context.Context, opts ...optpreview.Option) (Preview
 	if preOpts.UserAgent != "" {
 		sharedArgs = append(sharedArgs, fmt.Sprintf("--exec-agent=%s", preOpts.UserAgent))
 	}
+	if preOpts.Color != "" {
+		sharedArgs = append(sharedArgs, fmt.Sprintf("--color=%q", preOpts.Color))
+	}
 
 	kind, args := constant.ExecKindAutoLocal, []string{"preview"}
 	if program := s.Workspace().Program(); program != nil {
@@ -336,6 +339,9 @@ func (s *Stack) Up(ctx context.Context, opts ...optup.Option) (UpResult, error)
 	if upOpts.UserAgent != "" {
 		sharedArgs = append(sharedArgs, fmt.Sprintf("--exec-agent=%s", upOpts.UserAgent))
 	}
+	if upOpts.Color != "" {
+		sharedArgs = append(sharedArgs, fmt.Sprintf("--color=%q", upOpts.Color))
+	}
 
 	kind, args := constant.ExecKindAutoLocal, []string{"up", "--yes", "--skip-preview"}
 	if program := s.Workspace().Program(); program != nil {
@@ -417,6 +423,9 @@ func (s *Stack) Refresh(ctx context.Context, opts ...optrefresh.Option) (Refresh
 	if refreshOpts.UserAgent != "" {
 		args = append(args, fmt.Sprintf("--exec-agent=%s", refreshOpts.UserAgent))
 	}
+	if refreshOpts.Color != "" {
+		args = append(args, fmt.Sprintf("--color=%q", refreshOpts.Color))
+	}
 	execKind := constant.ExecKindAutoLocal
 	if s.Workspace().Program() != nil {
 		execKind = constant.ExecKindAutoInline
@@ -485,6 +494,9 @@ func (s *Stack) Destroy(ctx context.Context, opts ...optdestroy.Option) (Destroy
 	if destroyOpts.UserAgent != "" {
 		args = append(args, fmt.Sprintf("--exec-agent=%s", destroyOpts.UserAgent))
 	}
+	if destroyOpts.Color != "" {
+		args = append(args, fmt.Sprintf("--color=%q", destroyOpts.Color))
+	}
 	execKind := constant.ExecKindAutoLocal
 	if s.Workspace().Program() != nil {
 		execKind = constant.ExecKindAutoInline
@@ -938,7 +950,7 @@ func (s *languageRuntimeServer) Run(ctx context.Context, req *pulumirpc.RunReque
 		defer func() {
 			if r := recover(); r != nil {
 				if pErr, ok := r.(error); ok {
-					err = errors.Wrap(pErr, "go inline source runtime error, an unhandled error occurred:")
+					err = errors.Wrap(pErr, "go inline source runtime error, an unhandled error occurred")
 				} else {
 					err = errors.New("go inline source runtime error, an unhandled error occurred: unknown error")
 				}
