@@ -252,7 +252,7 @@ func (p *providerServer) Check(ctx context.Context, req *pulumirpc.CheckRequest)
 		return nil, err
 	}
 
-	newInputs, failures, err := p.provider.Check(urn, state, inputs, true)
+	newInputs, failures, err := p.provider.Check(urn, state, inputs, true, int(req.SequenceNumber))
 	if err != nil {
 		return nil, err
 	}
