@@ -333,6 +333,8 @@ func TestLargeResourceDotNet(t *testing.T) {
 // Test remote component construction in .NET.
 func TestConstructDotnet(t *testing.T) {
 	t.Skip() // TODO[pulumi/pulumi#7355] flaky test
+	t.Parallel()
+
 	tests := []struct {
 		componentDir          string
 		expectedResourceCount int
@@ -360,6 +362,7 @@ func TestConstructDotnet(t *testing.T) {
 	}
 
 	for _, test := range tests {
+		test := test
 		t.Run(test.componentDir, func(t *testing.T) {
 			pathEnv := pathEnv(t,
 				filepath.Join("..", "testprovider"),
@@ -378,8 +381,7 @@ func optsForConstructDotnet(t *testing.T, expectedResourceCount int, env ...stri
 		Secrets: map[string]string{
 			"secret": "this super secret is encrypted",
 		},
-		Quick:      true,
-		NoParallel: true, // avoid contention for Dir
+		Quick: true,
 		ExtraRuntimeValidation: func(t *testing.T, stackInfo integration.RuntimeValidationStackInfo) {
 			assert.NotNil(t, stackInfo.Deployment)
 			if assert.Equal(t, expectedResourceCount, len(stackInfo.Deployment.Resources)) {
@@ -451,6 +453,8 @@ func TestConstructSlowDotnet(t *testing.T) {
 
 // Test remote component construction with prompt inputs.
 func TestConstructPlainDotnet(t *testing.T) {
+	t.Parallel()
+
 	tests := []struct {
 		componentDir          string
 		expectedResourceCount int
@@ -478,6 +482,7 @@ func TestConstructPlainDotnet(t *testing.T) {
 	}
 
 	for _, test := range tests {
+		test := test
 		t.Run(test.componentDir, func(t *testing.T) {
 			pathEnv := pathEnv(t,
 				filepath.Join("..", "testprovider"),
@@ -494,7 +499,6 @@ func optsForConstructPlainDotnet(t *testing.T, expectedResourceCount int,
 		Env:          env,
 		Dir:          filepath.Join("construct_component_plain", "dotnet"),
 		Dependencies: []string{"Pulumi"},
-		NoParallel:   true, // avoid contention for Dir
 		Quick:        true,
 		ExtraRuntimeValidation: func(t *testing.T, stackInfo integration.RuntimeValidationStackInfo) {
 			assert.NotNil(t, stackInfo.Deployment)
@@ -510,6 +514,8 @@ func TestConstructUnknownDotnet(t *testing.T) {
 
 // Test methods on remote components.
 func TestConstructMethodsDotnet(t *testing.T) {
+	t.Parallel()
+
 	tests := []struct {
 		componentDir string
 	}{
@@ -524,6 +530,7 @@ func TestConstructMethodsDotnet(t *testing.T) {
 		},
 	}
 	for _, test := range tests {
+		test := test
 		t.Run(test.componentDir, func(t *testing.T) {
 			pathEnv := pathEnv(t, filepath.Join("construct_component_methods", test.componentDir))
 			integration.ProgramTest(t, &integration.ProgramTestOptions{
@@ -531,7 +538,6 @@ func TestConstructMethodsDotnet(t *testing.T) {
 				Dir:          filepath.Join("construct_component_methods", "dotnet"),
 				Dependencies: []string{"Pulumi"},
 				Quick:        true,
-				NoParallel:   true, // avoid contention for Dir
 				ExtraRuntimeValidation: func(t *testing.T, stackInfo integration.RuntimeValidationStackInfo) {
 					assert.Equal(t, "Hello World, Alice!", stackInfo.Outputs["message"])
 				},
@@ -549,6 +555,8 @@ func TestConstructMethodsErrorsDotnet(t *testing.T) {
 }
 
 func TestConstructProviderDotnet(t *testing.T) {
+	t.Parallel()
+
 	const testDir = "construct_component_provider"
 	tests := []struct {
 		componentDir string
@@ -564,6 +572,7 @@ func TestConstructProviderDotnet(t *testing.T) {
 		},
 	}
 	for _, test := range tests {
+		test := test
 		t.Run(test.componentDir, func(t *testing.T) {
 			pathEnv := pathEnv(t, filepath.Join(testDir, test.componentDir))
 			integration.ProgramTest(t, &integration.ProgramTestOptions{
@@ -571,7 +580,6 @@ func TestConstructProviderDotnet(t *testing.T) {
 				Dir:          filepath.Join(testDir, "dotnet"),
 				Dependencies: []string{"Pulumi"},
 				Quick:        true,
-				NoParallel:   true, // avoid contention for Dir
 				ExtraRuntimeValidation: func(t *testing.T, stackInfo integration.RuntimeValidationStackInfo) {
 					assert.Equal(t, "hello world", stackInfo.Outputs["message"])
 				},
@@ -592,6 +600,8 @@ func TestGetResourceDotnet(t *testing.T) {
 // results of each runtime independently, we have an integration test in each
 // language.
 func TestAboutDotnet(t *testing.T) {
+	t.Parallel()
+
 	dir := filepath.Join("about", "dotnet")
 
 	e := ptesting.NewEnvironment(t)
